@@ -484,9 +484,9 @@ class Scratch2Py():
             data = []
             while True:
                 encodedMethod = self.__readCloudVar('Method')
-                if Method != None:
+                if encodedMethod != None:
                     Method = encoder.decode(encodedMethod)
-                if encodedMethod == "set":
+                if Method == "set":
                     encodedSend = self.__readCloudVar('Send')
                     Send = str(encoder.decode(encodedSend))
                     encodedVal = self.__readCloudVar('Data')
